@@ -232,7 +232,10 @@ class BuildExtension(build_ext):
         # Call CMake
         subprocess.check_call(configure_command)
         subprocess.check_call(build_command)
-        subprocess.check_call(install_command)
+        try:
+            subprocess.check_call(install_command)
+        except Exception as e:
+            print("WARNING: " , e, file=sys.stderr)
 
         # Write content to the top-level __init__.py
         if ext.write_top_level_init is not None:
